@@ -21,8 +21,10 @@ import aws_cdk.aws_appintegrations._jsii
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_applicationinsights._jsii
 import aws_cdk.aws_appmesh._jsii
+import aws_cdk.aws_apprunner._jsii
 import aws_cdk.aws_appstream._jsii
 import aws_cdk.aws_appsync._jsii
+import aws_cdk.aws_aps._jsii
 import aws_cdk.aws_athena._jsii
 import aws_cdk.aws_auditmanager._jsii
 import aws_cdk.aws_autoscaling._jsii
@@ -50,6 +52,8 @@ import aws_cdk.aws_codestarconnections._jsii
 import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_config._jsii
+import aws_cdk.aws_connect._jsii
+import aws_cdk.aws_cur._jsii
 import aws_cdk.aws_customerprofiles._jsii
 import aws_cdk.aws_databrew._jsii
 import aws_cdk.aws_datapipeline._jsii
@@ -76,8 +80,10 @@ import aws_cdk.aws_emr._jsii
 import aws_cdk.aws_emrcontainers._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_eventschemas._jsii
+import aws_cdk.aws_finspace._jsii
 import aws_cdk.aws_fis._jsii
 import aws_cdk.aws_fms._jsii
+import aws_cdk.aws_frauddetector._jsii
 import aws_cdk.aws_fsx._jsii
 import aws_cdk.aws_gamelift._jsii
 import aws_cdk.aws_globalaccelerator._jsii
@@ -86,12 +92,14 @@ import aws_cdk.aws_greengrass._jsii
 import aws_cdk.aws_greengrassv2._jsii
 import aws_cdk.aws_groundstation._jsii
 import aws_cdk.aws_guardduty._jsii
+import aws_cdk.aws_healthlake._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_imagebuilder._jsii
 import aws_cdk.aws_inspector._jsii
 import aws_cdk.aws_iot._jsii
 import aws_cdk.aws_iot1click._jsii
 import aws_cdk.aws_iotanalytics._jsii
+import aws_cdk.aws_iotcoredeviceadvisor._jsii
 import aws_cdk.aws_iotevents._jsii
 import aws_cdk.aws_iotfleethub._jsii
 import aws_cdk.aws_iotsitewise._jsii
@@ -106,7 +114,9 @@ import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lakeformation._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_licensemanager._jsii
+import aws_cdk.aws_location._jsii
 import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_lookoutequipment._jsii
 import aws_cdk.aws_lookoutmetrics._jsii
 import aws_cdk.aws_lookoutvision._jsii
 import aws_cdk.aws_macie._jsii
@@ -122,6 +132,7 @@ import aws_cdk.aws_neptune._jsii
 import aws_cdk.aws_networkfirewall._jsii
 import aws_cdk.aws_networkmanager._jsii
 import aws_cdk.aws_nimblestudio._jsii
+import aws_cdk.aws_opensearchservice._jsii
 import aws_cdk.aws_opsworks._jsii
 import aws_cdk.aws_opsworkscm._jsii
 import aws_cdk.aws_pinpoint._jsii
@@ -134,6 +145,8 @@ import aws_cdk.aws_redshift._jsii
 import aws_cdk.aws_resourcegroups._jsii
 import aws_cdk.aws_robomaker._jsii
 import aws_cdk.aws_route53._jsii
+import aws_cdk.aws_route53recoverycontrol._jsii
+import aws_cdk.aws_route53recoveryreadiness._jsii
 import aws_cdk.aws_route53resolver._jsii
 import aws_cdk.aws_s3._jsii
 import aws_cdk.aws_s3objectlambda._jsii
@@ -151,6 +164,8 @@ import aws_cdk.aws_signer._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_ssm._jsii
+import aws_cdk.aws_ssmcontacts._jsii
+import aws_cdk.aws_ssmincidents._jsii
 import aws_cdk.aws_sso._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.aws_synthetics._jsii
@@ -160,14 +175,15 @@ import aws_cdk.aws_waf._jsii
 import aws_cdk.aws_wafregional._jsii
 import aws_cdk.aws_wafv2._jsii
 import aws_cdk.aws_workspaces._jsii
+import aws_cdk.aws_xray._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.103.0",
+    "1.124.0",
     __name__[0:-6],
-    "cloudformation-include@1.103.0.jsii.tgz",
+    "cloudformation-include@1.124.0.jsii.tgz",
 )
 
 __all__ = [
